@@ -10,7 +10,7 @@ int main(int argc, char *argv[])
 	QCoreApplication::setAttribute(Qt::AA_NativeWindows, true);
 
 	// Initialise the configuration directory
-	ClassicPrintSettings::init("/opt/classicprint");
+	ClassicPrintSettings::init("/opt/classiccam");
 
 	QApplication a(argc, argv);
 	MainWindow w;
