@@ -30,7 +30,7 @@ MainWindow::MainWindow(QWidget *parent) :
 
 	m_maximum_to_process = 0;
 	m_process_preview = true;
-	m_camera_mp = 5;
+	m_camera_mp = 3;
 	m_keep_negatives = true;
 
 	// Initialise the ClassicPrint library
@@ -38,6 +38,10 @@ MainWindow::MainWindow(QWidget *parent) :
 
 	ui->setupUi(this);
 
+	// Set some default settings for the case where there is not configuration file
+	m_negatives_folder = "/home/user/MyDocs/ClassicPhotos/Negatives/";
+	m_developed_folder = "/home/user/MyDocs/ClassicPhotos/Developed/";
+
 	// Load the initial settings
 	load_settings();
 
